
#ifndef _C12_fi555_
#define _C12_fi555_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F556_2770(EIF_REFERENCE);
extern void EIF_Minit555(void);
extern EIF_INTEGER_32 F658_3248(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
